@@ -26,7 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <math.h>  
 #include <stdio.h>  
 #include <stdlib.h>
-#include <sys/timeb.h>
+//#include <sys/timeb.h>
 #include <assert.h>
 #include <string.h>
 #include "RFsimu.h"
